## 4.2.3 (2021-10-11)

Fix type of lock parameter of cachetools.cachedmethod() decorator (#6144)

## 4.2.2 (2021-09-30)

Remove unncessary MutableMapping overrides (#6097)

## 4.2.1 (2021-09-30)

Add back and update cachetools stubs to cachetools 4.2.4 (#6096)

